@@ -23,13 +23,20 @@
 
 #ifndef MOLEQUEUESERVERCORE_DEPRECATED
 #  define MOLEQUEUESERVERCORE_DEPRECATED __attribute__ ((__deprecated__))
-#  define MOLEQUEUESERVERCORE_DEPRECATED_EXPORT MOLEQUEUESERVERCORE_EXPORT __attribute__ ((__deprecated__))
-#  define MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT MOLEQUEUESERVERCORE_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define MOLEQUEUESERVERCORE_NO_DEPRECATED
+#ifndef MOLEQUEUESERVERCORE_DEPRECATED_EXPORT
+#  define MOLEQUEUESERVERCORE_DEPRECATED_EXPORT MOLEQUEUESERVERCORE_EXPORT MOLEQUEUESERVERCORE_DEPRECATED
+#endif
+
+#ifndef MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT
+#  define MOLEQUEUESERVERCORE_DEPRECATED_NO_EXPORT MOLEQUEUESERVERCORE_NO_EXPORT MOLEQUEUESERVERCORE_DEPRECATED
+#endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef MOLEQUEUESERVERCORE_NO_DEPRECATED
+#    define MOLEQUEUESERVERCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
